@@ -28,6 +28,7 @@ import sys
 from functools import wraps
 from requests.compat import urljoin
 from praw import errors
+from warnings import warn
 
 
 # Don't decorate functions when building the documentation
@@ -62,6 +63,22 @@ def alias_function(function, class_name):
     return wrapped
 
 
+def depreciated(msg=""):
+    """Depreciate decorated methods."""
+    docstring_text = ("**DEPRECIATED**. Will be removed in a future version "
+                      "of PRAW. %s" % msg)
+
+    def wrap(function):
+        warn(msg, DeprecationWarning)
+        function.__doc__ = _embed_text(function.__doc__, docstring_text)
+
+        @wraps(function)
+        def wrapped(self, *args, **kwargs):
+            return function(args, kwargs)
+        return function if IS_SPHINX_BUILD else wrapped
+    return wrap
+
+
 def limit_chars(function):
     """Truncate the string returned from a function and return the result."""
     @wraps(function)
