@@ -29,7 +29,8 @@ from praw import (AuthenticatedReddit as AR, ModConfigMixin as MCMix,
                   ModFlairMixin as MFMix, ModLogMixin as MLMix,
                   ModOnlyMixin as MOMix, PrivateMessagesMixin as PMMix,
                   SubmitMixin, SubscribeMixin, UnauthenticatedReddit as UR)
-from praw.decorators import alias_function, limit_chars, restrict_access
+from praw.decorators import (alias_function, depreciated, limit_chars,
+                             restrict_access)
 from praw.errors import ClientException
 from praw.internal import (_get_redditor_listing, _get_sorter,
                            _modify_relationship)
@@ -182,6 +183,19 @@ class Moderatable(RedditContentObject):
                 'how': 'yes' if as_made_by == 'mod' else as_made_by}
         return self.reddit_session.request_json(url, data=data)
 
+    @restrict_access(scope='modposts')
+    def ignore_reports(self):
+        """Ignore future reports on this object.
+
+        This prevents future reports from causing notifications or appearing
+        in the various moderation listing. The report count will still
+        increment.
+
+        """
+        url = self.reddit_session.config['ignore_reports']
+        data = {'id': self.fullname}
+        return self.reddit_session.request_json(url, data=data)
+
     @restrict_access(scope='modposts')
     def remove(self, spam=False):
         """Remove object. This is the moderator version of delete.
@@ -211,6 +225,18 @@ class Moderatable(RedditContentObject):
         """
         return self.distinguish(as_made_by='no')
 
+    @restrict_access(scope='modposts')
+    def unignore_reports(self):
+        """Remove ignoring of future reports on this object.
+
+        Undoes 'ignore_reports'. Future reports will now cause notifications
+        and appear in the various moderation listings.
+
+        """
+        url = self.reddit_session.config['unignore_reports']
+        data = {'id': self.fullname}
+        return self.reddit_session.request_json(url, data=data)
+
 
 class Editable(RedditContentObject):
 
@@ -610,8 +636,6 @@ class Redditor(Messageable, Refreshable):
     """A class representing the users of reddit."""
 
     get_comments = _get_redditor_listing('comments')
-    get_disliked = _get_redditor_listing('disliked')
-    get_liked = _get_redditor_listing('liked')
     get_overview = _get_redditor_listing('')
     get_submitted = _get_redditor_listing('submitted')
 
@@ -647,6 +671,35 @@ class Redditor(Messageable, Refreshable):
         self.reddit_session.evict(self.reddit_session.config['friends'])
         return _modify_relationship('friend')(self.reddit_session.user, self)
 
+    def get_disliked(self):
+        """Return a listing of the things the user has downvoted.
+
+        As a default, this listing is only accessible by the user. Thereby
+        requirering either user/pswd authentication or OAuth authentication
+        with the 'history' scope. Users may choose to make their voting record
+        public by changing a user preference. In this case, no authentication
+        will be needed to access this listing.
+
+        """
+        # Sending an OAuth authenticated request for a redditor, who isn't the
+        # authenticated user. But who has a public voting record will be
+        # successful.
+        use_oauth = self.reddit_session.is_oauth_session()
+        return _get_redditor_listing('disliked')(self, _use_oauth=use_oauth)
+
+    def get_liked(self):
+        """Return a listing of the things the user has upvoted.
+
+        As a default, this listing is only accessible by the user. Thereby
+        requirering either user/pswd authentication or OAuth authentication
+        with the 'history' scope. Users may choose to make their voting record
+        public by changing a user preference. In this case, no authentication
+        will be needed to access this listing.
+
+        """
+        use_oauth = self.reddit_session.is_oauth_session()
+        return _get_redditor_listing('liked')(self, _use_oauth=use_oauth)
+
     def mark_as_read(self, messages, unread=False):
         """Mark message(s) as read or unread.
 
@@ -684,8 +737,8 @@ class LoggedInRedditor(Redditor):
 
     """A class representing a currently logged in Redditor."""
 
-    get_hidden = _get_redditor_listing('hidden')
-    get_saved = _get_redditor_listing('saved')
+    get_hidden = restrict_access("history")(_get_redditor_listing('hidden'))
+    get_saved = restrict_access("history")(_get_redditor_listing('saved'))
 
     def get_blocked(self):
         """Return a UserList of Redditors with whom the user has blocked."""
@@ -706,7 +759,12 @@ class LoggedInRedditor(Redditor):
         return self._mod_subs
 
     def get_friends(self):
-        """Return a UserList of Redditors with whom the user has friended."""
+        """Return a UserList of Redditors with whom the user has friended.
+
+        Will throw a RedirectException while
+        https://github.com/praw-dev/praw/issues/175 is unresolved.
+
+        """
         url = self.reddit_session.config['friends']
         return self.reddit_session.request_json(url)[0]
 
@@ -1080,20 +1138,25 @@ class Subreddit(Messageable, Refreshable):
 
     # Subreddit banned
     add_ban = _modify_relationship('banned', is_sub=True)
-    ban = _modify_relationship('banned', is_sub=True, deprecated='add_ban')
-    unban = _modify_relationship('banned', unlink=True, is_sub=True,
-                                 deprecated='remove_ban')
+    ban = (depreciated(msg="Please use `add_ban` instead.")
+                      (_modify_relationship('banned', is_sub=True)))
+    unban = (depreciated(msg="Please use `remove_ban` instead.")
+                        (_modify_relationship('banned', unlink=True,
+                                              is_sub=True)))
     remove_ban = _modify_relationship('banned', unlink=True, is_sub=True)
     # Subreddit contributors
     add_contributor = _modify_relationship('contributor', is_sub=True)
-    make_contributor = _modify_relationship('contributor', is_sub=True,
-                                            deprecated='add_contributor')
+    make_contributor = (depreciated(msg="Please use `add_contributor` "
+                                        "instead.")
+                                   (_modify_relationship('contributor',
+                                                         is_sub=True)))
     remove_contributor = _modify_relationship('contributor', unlink=True,
                                               is_sub=True)
     # Subreddit moderators
     add_moderator = _modify_relationship('moderator', is_sub=True)
-    make_moderator = _modify_relationship('moderator', is_sub=True,
-                                          deprecated='add_moderator')
+    make_moderator = (depreciated(msg="Please use `add_moderator` instead.")
+                                 (_modify_relationship('moderator',
+                                                       is_sub=True)))
     remove_moderator = _modify_relationship('moderator', unlink=True,
                                             is_sub=True)
     # Subreddit wiki banned
@@ -1118,8 +1181,10 @@ class Subreddit(Messageable, Refreshable):
     get_controversial_from_month = _get_sorter('controversial', t='month')
     get_controversial_from_week = _get_sorter('controversial', t='week')
     get_controversial_from_year = _get_sorter('controversial', t='year')
-    get_new_by_date = _get_sorter('new', deprecated='get_new')
-    get_new_by_rising = _get_sorter('rising', deprecated='get_rising')
+    get_new_by_date = (depreciated(msg="Please use `get_new` instead.")
+                                  (_get_sorter('new')))
+    get_new_by_rising = (depreciated(msg="Please use `get_rising` instead.")
+                                    (_get_sorter('rising')))
     get_rising = _get_sorter('rising')
     get_top_from_all = _get_sorter('top', t='all')
     get_top_from_day = _get_sorter('top', t='day')
