@@ -367,7 +367,7 @@ class BasicTest(unittest.TestCase, BasicHelper):
     def test_search_with_time_window(self):
         num = 50
         submissions = len(list(self.r.search('test', subreddit=self.sr,
-                                             period='week', limit=num)))
+                                             period='all', limit=num)))
         self.assertTrue(submissions == num)
 
     def test_search_reddit_names(self):
@@ -1078,6 +1078,16 @@ class ModeratorSubmissionTest(unittest.TestCase, AuthenticatedHelper):
         predicate = lambda approved: approved.id == submission.id
         self.first(self.subreddit.get_new(), predicate)
 
+    def test_ignore_reports(self):
+        submission = next(self.subreddit.get_new())
+        self.assertFalse(submission in self.subreddit.get_mod_log())
+        submission.ignore_reports()
+        submission.report()
+        self.disable_cache()
+        submission.refresh()
+        self.assertFalse(submission in self.subreddit.get_mod_log())
+        self.assertTrue(submission.num_reports > 0)
+
     def test_remove(self):
         submission = next(self.subreddit.get_new())
         if not submission:
@@ -1431,6 +1441,10 @@ class RedditorTest(unittest.TestCase, AuthenticatedHelper):
     def test_get_redditor(self):
         self.assertEqual(self.other_user_id, self.other_user.id)
 
+    def test_get_submitted(self):
+        redditor = self.r.get_redditor(self.other_non_mod_name)
+        self.assertTrue(list(redditor.get_submitted()))
+
     def test_user_set_on_login(self):
         self.assertTrue(isinstance(self.r.user, LoggedInRedditor))
 
@@ -1620,6 +1634,7 @@ class SubmissionTest(unittest.TestCase, AuthenticatedHelper):
         self.assertTrue(submission.hidden)
 
     def test_report(self):
+        self.disable_cache()
         # login as new user to report submission
         oth = Reddit(USER_AGENT, disable_update_check=True)
         oth.login(self.other_user_name, self.other_user_pswd)
